stalker.core.models.ImageFormat — Stalker v0.1.1.a9 documentation

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »

# stalker.core.models.ImageFormat

class `stalker.core.models.` `ImageFormat`(width=None, height=None, pixel_aspect=1.0, print_resolution=300, **kwargs)

  Bases: `stalker.core.models.Entity`

  Common image formats for the projects.

  adds up this parameters to the SimpleEntity:

  Parameters: | width – the width of the format, it cannot be zero or negative, if a float number is given it will be converted to integer height – the height of the format, it cannot be zero or negative, if a float number is given it will be converted to integer pixel_aspect – the pixel aspect ratio of the current ImageFormat object, it can not be zero or negative, and if given as an integer it will be converted to a float, the default value is 1.0 print_resolution – the print resolution of the ImageFormat given as DPI (dot-per-inch). It can not be zero or negative

  `__init__`(width=None, height=None, pixel_aspect=1.0, print_resolution=300, **kwargs)

  Methods

  `__init__`(**kwargs[, width, height, ...]) |

  Attributes

  `code` | The code name of this object.
  `created_by` | The `User` who has created this object.
  `date_created` | A `datetime.datetime` instance showing the creation date and time of this object.
  `date_updated` | A `datetime.datetime` instance showing the update date and time of this object.
  `description` | Description of this object.
  `device_aspect` | returns the device aspect
  `height` | this is a property to set and get the height of the
  `name` | Name of this object
  `nice_name` | Nice name of this object.
  `notes` | All the notes about this entity.
  `pixel_aspect` | this is a property to set and get the pixel_aspect of the
  `print_resolution` | this is a property to set and get the print_resolution of the
  `tags` | A list of tags attached to this object.
  `type` | The type of the object.
  `updated_by` | The `User` who has updated this object.
  `width` | this is a property to set and get the width of the

  `width`

    this is a property to set and get the width of the image_format

    - the width should be set to a positif non-zero integer
    - integers are also accepted but will be converted to float
    - for improper inputs the object will raise an exception.
  `height`

    this is a property to set and get the height of the image_format

    - the height should be set to a positif non-zero integer
    - integers are also accepted but will be converted to float
    - for improper inputs the object will raise an exception.
  `pixel_aspect`

    this is a property to set and get the pixel_aspect of the ImageFormat

    - the pixel_aspect should be set to a positif non-zero float
    - integers are also accepted but will be converted to float
    - for improper inputs the object will raise an exception
  `device_aspect`

    returns the device aspect

    because the device_aspect is calculated from the width/height*pixel formula, this property is read-only.

  `print_resolution`

    this is a property to set and get the print_resolution of the ImageFormat

    - it should be set to a positif non-zero float or integer
    - integers are also accepted but will be converted to float
    - for improper inputs the object will raise an exception.
  `code`

    The code name of this object.

    It accepts string or unicode values and any other kind of objects will be converted to string. In any update to the name attribute the code also will be updated. If the code is not initialized or given as None, it will be set to the uppercase version of the nice_name attribute. Setting the code attribute to None will reset it to the default value. The default value is the upper case form of the nice_name.

  `created_by`

    The `User` who has created this object.

  `date_created`

    A `datetime.datetime` instance showing the creation date and time of this object.

  `date_updated`

    A `datetime.datetime` instance showing the update date and time of this object.

  `description`

    Description of this object.

  `name`

    Name of this object

  `nice_name`

    Nice name of this object.

    It has the same value with the name (contextually) but with a different format like, all the white spaces replaced by underscores (“_”), all the CamelCase form will be expanded by underscore (_) characters and it is always lower case.

    There is also the `code` attribute which is simply the upper case form of `nice_name` if it is not defined differently (i.e set to another value).

  `notes`

    All the notes about this entity.

    It is a list of `Note` objects or an empty list, None will be converted to an empty list.

  `tags`

    A list of tags attached to this object.

    It is a list of `Tag` instances which shows the tags of this object

  `type`

    The type of the object.

    It is an instance of `Type` with a proper `target_entity_type`.

  `updated_by`

    The `User` who has updated this object.

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »